/**
 * This file is part of the CernVM File System.
 */

#include <gtest/gtest.h>

#include "wpad.h"

using namespace std;  // NOLINT

class T_Wpad : public ::testing::Test {
 protected:
  virtual void SetUp() { }

  virtual void TearDown() { }
};


TEST_F(T_Wpad, Init) { }
